==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/DeleteVoiceChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class DeleteVoiceChannelRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest = {
    import DeleteVoiceChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.DeleteVoiceChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.DeleteVoiceChannelRequest.wrap(buildAwsValue())
}
object DeleteVoiceChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.DeleteVoiceChannelRequest =
      zio.aws.pinpoint.model.DeleteVoiceChannelRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest
  ) extends zio.aws.pinpoint.model.DeleteVoiceChannelRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest
  ): zio.aws.pinpoint.model.DeleteVoiceChannelRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/DeleteVoiceChannelRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class DeleteVoiceChannelRequest(applicationId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest = {
    import DeleteVoiceChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.DeleteVoiceChannelRequest.ReadOnly =
    zio.aws.pinpoint.model.DeleteVoiceChannelRequest.wrap(buildAwsValue())
}
object DeleteVoiceChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.DeleteVoiceChannelRequest =
      zio.aws.pinpoint.model.DeleteVoiceChannelRequest(applicationId)
    def applicationId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest
  ) extends zio.aws.pinpoint.model.DeleteVoiceChannelRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.DeleteVoiceChannelRequest
  ): zio.aws.pinpoint.model.DeleteVoiceChannelRequest.ReadOnly = new Wrapper(
    impl
  )
}
